////////////////////////////////////////////////////////////////////////////////////////////
// File      : s2218_core.h
// Project   : Sensoray model 2218 API
// Function  : Generic HAL interface for portable API core (s2218_core.c)
// System    : OS independent
////////////////////////////////////////////////////////////////////////////////////////////

#ifndef _S2218_CORE_H_
#define _S2218_CORE_H_

#define _BUILD_S2218_MIDDLEWARE_     // indicate building API (vs. application)

#define S2218_BUFSIZE   63

// OS-dependent functions implemented in s2218_platform.c --------------------

struct HID_DEVICE_;
typedef struct HID_DEVICE_ HID_DEVICE; // abstract hidapi structure

int             hid_system_close(void);
int             hid_system_open(void);
int             hid_devices_detect(u16 vendor_id, u16 product_id, int *devflags);
int             hid_device_open(unsigned short vendor_id, unsigned short product_id, unsigned int devaddr, unsigned short *hw_version, HID_DEVICE **pdev);
int             hid_device_write(HID_DEVICE *dev, const unsigned char *data, size_t datalen);
int             hid_device_read(HID_DEVICE *dev, unsigned char *data, size_t length);
int             hid_device_stop_poll(HID_DEVICE *dev);
void            hid_device_close(HID_DEVICE *dev);

S2218_HANDLE    sysCreateSemaphore(int maxcount);
void            sysDestroySemaphore(S2218_HANDLE hSem);
int             sysPostSemaphore(S2218_HANDLE hSem);
int             sysPendSemaphore(S2218_HANDLE hSem, unsigned int msec);

S2218_HANDLE    sysCreateMutex(void);
void            sysDestroyMutex(S2218_HANDLE hMutex);
void            sysPostMutex(S2218_HANDLE hMutex);
int             sysPendMutex(S2218_HANDLE hMutex, unsigned int msec);

S2218_HANDLE    sysCreateThread(void *func, void *arg);
void            sysPendThread(S2218_HANDLE hThread);
int             sysThreadStatus(S2218_HANDLE hThread);

#endif // ifndef _S2218_CORE_H_
